# Generated by Django 5.1.3 on 2024-11-08 16:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("uk_geo_utils", "0009_onspd_lsoa21_onspd_msoa21_onspd_oa21"),
    ]

    operations = [
        migrations.RenameField(
            model_name="onspd",
            old_name="bua11",
            new_name="bua22",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="nuts",
            new_name="itl",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="park",
            new_name="npark",
        ),
        migrations.RemoveField(
            model_name="onspd",
            name="buasd11",
        ),
        migrations.RemoveField(
            model_name="onspd",
            name="ccg",
        ),
        migrations.RemoveField(
            model_name="onspd",
            name="stp",
        ),
        migrations.AddField(
            model_name="onspd",
            name="icb",
            field=models.CharField(blank=True, max_length=9),
        ),
        migrations.AddField(
            model_name="onspd",
            name="sicbl",
            field=models.CharField(blank=True, max_length=9),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lsoa21",
            field=models.CharField(blank=True, default="", max_length=9),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="onspd",
            name="msoa21",
            field=models.CharField(blank=True, default="", max_length=9),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="onspd",
            name="oa21",
            field=models.CharField(blank=True, default="", max_length=9),
            preserve_default=False,
        ),
    ]
